# Table of Contents

- [views-aggregation](<./views-aggregation.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Views Aggregation](<./Views-Aggregation.md>)
  - [Views Aggregation](<./Views-Aggregation/Views-Aggregation.md>)
  - [Selecting a Related Fact Sheet](<./Views-Aggregation/Selecting-a-Related-Fact-Sheet.md>)
  - [Obsolescence Risk View Aggregation](<./Views-Aggregation/Obsolescence-Risk-View-Aggregation.md>)
  - [Obsolescence Risk Details](<./Views-Aggregation/Obsolescence-Risk-Details.md>)
  - [Was this page helpful?](<./Views-Aggregation/Was-this-page-helpful.md>)
  - [We'd love your feedback!](<./Views-Aggregation/Wed-love-your-feedback.md>)
